===============================
PySugarCRM
===============================

.. image:: https://img.shields.io/travis/dnmellen/pysugarcrm.svg
        :target: https://travis-ci.org/dnmellen/pysugarcrm

.. image:: https://img.shields.io/pypi/v/pysugarcrm.svg
        :target: https://pypi.python.org/pypi/pysugarcrm


Python API Wrapper for SugarCRM v10

* Free software: BSD license
* Documentation: https://pysugarcrm.readthedocs.org.

Features
--------

* TODO